@@ -1,5 +1,5 @@
 package Telegram::Bot;
-$Telegram::Bot::VERSION = '0.012';
+$Telegram::Bot::VERSION = '0.020';
 use strict;
 use warnings;
 
@@ -20,7 +20,7 @@ Telegram::Bot - A base class to make your very own Telegram bot
 
 =head1 VERSION
 
-version 0.012
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -29,7 +29,7 @@ NOTE: This API should not yet be considered stable.
 Creating a bot is easy:
 
     package MyBot;
-    
+
     use Mojo::Base 'Telegram::Bot::Brain';
 
     has token => 'YOURTOKENHERE';
@@ -49,27 +49,25 @@ Creating a bot is easy:
     sub _be_polite {
       my ($self, $msg) = @_;
 
+      return unless $msg->text =~ /hello/;
+
       # is this a 1-on-1 ?
       if ($msg->chat->is_user) {
-        $self->send_message_to_chat_id($msg->chat->id, "hello there");
+        $msg->reply("hello there");
 
         # send them a picture as well
-        my $image = Telegram::Bot::Object::PhotoSize->new(image => "smile.png");
-        $self->send_to_chat_id($msg->chat->id, $image);
+        $self->sendPhoto({chat_id => $msg->chat->id, photo => $image_filename});
       }
       # group chat
       else {
-        $self->send_message_to_chat_id($msg->chat->id, "hello to everyone!");
+        $msg->reply("hello to everyone!");
       }
     }
 
     # setup our bot
     sub init {
       my $self = shift;
-      $self->add_listener(\&_hello_for_me,  # criteria
-                          \&_be_polite      # response
-                         ); 
- 
+      $self->add_listener(\&_be_polite);
     }
 
     1;
@@ -89,7 +87,7 @@ Justin Hawkins <justin@eatmorecode.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Justin Hawkins.
+This software is copyright (c) 2019 by Justin Hawkins.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
