@@ -1,7 +1,8 @@
 package Telegram::Bot::Object::Contact;
-$Telegram::Bot::Object::Contact::VERSION = '0.012';
+$Telegram::Bot::Object::Contact::VERSION = '0.020';
 # ABSTRACT: The base class for Telegram 'Contact' objects.
 
+
 use Mojo::Base 'Telegram::Bot::Object::Base';
 
 has 'phone_number';
@@ -28,7 +29,12 @@ Telegram::Bot::Object::Contact - The base class for Telegram 'Contact' objects.
 
 =head1 VERSION
 
-version 0.012
+version 0.020
+
+=head1 DESCRIPTION
+
+See L<https://core.telegram.org/bots/api#chat> for details of the
+attributes available for L<Telegram::Bot::Object::Contact> objects.
 
 =head1 AUTHOR
 
@@ -36,7 +42,7 @@ Justin Hawkins <justin@eatmorecode.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Justin Hawkins.
+This software is copyright (c) 2019 by Justin Hawkins.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
