@@ -1,22 +1,21 @@
 package Telegram::Bot::Object::Document;
-$Telegram::Bot::Object::Document::VERSION = '0.012';
+$Telegram::Bot::Object::Document::VERSION = '0.020';
 # ABSTRACT: The base class for Telegram 'Document' objects
 
+
 use Mojo::Base 'Telegram::Bot::Object::Base';
 
 use Telegram::Bot::Object::PhotoSize;
 
 has 'file_id';
-has 'thumb';
+has 'thumb'; #PhotoSize
 has 'file_name';
 has 'mime_type';
 has 'file_size';
 
-sub is_array { return; }
-
 sub fields {
   return { scalar => [qw/file_id file_name mime_type file_size/],
-           'Telegram::Bot::Message::PhotoSize' => [qw/thumb/]
+           'Telegram::Bot::Object::PhotoSize' => [qw/thumb/]
          };
 }
 
@@ -34,7 +33,12 @@ Telegram::Bot::Object::Document - The base class for Telegram 'Document' objects
 
 =head1 VERSION
 
-version 0.012
+version 0.020
+
+=head1 DESCRIPTION
+
+See L<https://core.telegram.org/bots/api#document> for details of the
+attributes available for L<Telegram::Bot::Object::Document> objects.
 
 =head1 AUTHOR
 
@@ -42,7 +46,7 @@ Justin Hawkins <justin@eatmorecode.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Justin Hawkins.
+This software is copyright (c) 2019 by Justin Hawkins.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
